from pyalexs3.core import OpenAlexS3Processor


def test_extract_date_and_fmt():
    p = OpenAlexS3Processor()

    extract = p._OpenAlexS3Processor__extract_date
    checkfmt = p._OpenAlexS3Processor__check_date_fmt

    key = "data/works/updated_date=2025-07-05/part_000.gz"
    assert extract(key) == "2025-07-05"

    assert checkfmt("2025-07-05") is True
    assert checkfmt("2025-7-5") is False
    assert checkfmt("not-a-date") is False



from importlib.metadata import PackageNotFoundError, version

try:
    __version__ = version("pyalexs3")
except PackageNotFoundError:
    __version__ = "0.0.0"

from .core import OpenAlexS3Processor

__all__ = ["OpenAlexS3Processor", "__version__"]



WORKS_SCHEMA = {
    "id": "VARCHAR",
    "doi": "VARCHAR",
    "title": "VARCHAR",
    "display_name": "VARCHAR",
    "publication_year": "BIGINT",
    "publication_date": "VARCHAR",
    "ids": "STRUCT(openalex VARCHAR, doi VARCHAR, mag VARCHAR, pmid VARCHAR, pmcid VARCHAR)",
    "language": "VARCHAR",
    "primary_location": "STRUCT(is_oa BOOLEAN, landing_page_url VARCHAR, pdf_url VARCHAR, source STRUCT(id VARCHAR, display_name VARCHAR, issn_l VARCHAR, issn VARCHAR[], is_oa BOOLEAN, is_in_doaj BOOLEAN, is_indexed_in_scopus BOOLEAN, is_core BOOLEAN, host_organization VARCHAR, host_organization_name VARCHAR, host_organization_lineage VARCHAR[], host_organization_lineage_names VARCHAR[], type VARCHAR), license VARCHAR, license_id VARCHAR, is_accepted BOOLEAN, is_published BOOLEAN)",
    "type": "VARCHAR",
    "type_crossref": "VARCHAR",
    "indexed_in": "VARCHAR[]",
    "open_access": "STRUCT(is_oa BOOLEAN, oa_status VARCHAR, oa_url VARCHAR, any_repository_has_fulltext BOOLEAN)",
    "authorships": "STRUCT(author_position VARCHAR, author STRUCT(id VARCHAR, display_name VARCHAR, orcid VARCHAR), institutions STRUCT(id VARCHAR, display_name VARCHAR, ror VARCHAR, country_code VARCHAR, type VARCHAR, lineage VARCHAR[])[], countries VARCHAR[], is_corresponding BOOLEAN, raw_author_name VARCHAR, raw_affiliation_strings VARCHAR[], affiliations STRUCT(raw_affiliation_string VARCHAR, institution_ids VARCHAR[])[])[]",
    "abstract_inverted_index": "MAP(VARCHAR, BIGINT[])",
    "institution_assertions": "VARCHAR[]",
    "countries_distinct_count": "BIGINT",
    "institutions_distinct_count": "BIGINT",
    "corresponding_author_ids": "VARCHAR[]",
    "corresponding_institution_ids": "VARCHAR[]",
    "apc_list": "STRUCT(value BIGINT, currency VARCHAR, value_usd BIGINT)",
    "apc_paid": "STRUCT(value BIGINT, currency VARCHAR, value_usd BIGINT)",
    "fwci": "DOUBLE",
    "has_fulltext": "BOOLEAN",
    "fulltext_origin": "VARCHAR",
    "cited_by_count": "BIGINT",
    "citation_normalized_percentile": "STRUCT(value DOUBLE, is_in_top_1_percent BOOLEAN, is_in_top_10_percent BOOLEAN)",
    "cited_by_percentile_year": "STRUCT(min BIGINT, max BIGINT)",
    "biblio": "STRUCT(volume VARCHAR, issue VARCHAR, first_page VARCHAR, last_page VARCHAR)",
    "is_retracted": "BOOLEAN",
    "is_paratext": "BOOLEAN",
    "primary_topic": "STRUCT(id VARCHAR, display_name VARCHAR, score DOUBLE, subfield STRUCT(id VARCHAR, display_name VARCHAR), field STRUCT(id VARCHAR, display_name VARCHAR), domain STRUCT(id VARCHAR, display_name VARCHAR))",
    "topics": "STRUCT(id VARCHAR, display_name VARCHAR, score DOUBLE, subfield STRUCT(id VARCHAR, display_name VARCHAR), field STRUCT(id VARCHAR, display_name VARCHAR), domain STRUCT(id VARCHAR, display_name VARCHAR))[]",
    "keywords": "STRUCT(id VARCHAR, display_name VARCHAR, score DOUBLE)[]",
    "concepts": "STRUCT(id VARCHAR, wikidata VARCHAR, display_name VARCHAR, level BIGINT, score DOUBLE)[]",
    "mesh": "STRUCT(descriptor_ui VARCHAR, descriptor_name VARCHAR, qualifier_ui VARCHAR, qualifier_name VARCHAR, is_major_topic BOOLEAN)[]",
    "locations_count": "BIGINT",
    "locations": "STRUCT(is_oa BOOLEAN, landing_page_url VARCHAR, pdf_url VARCHAR, source STRUCT(id VARCHAR, display_name VARCHAR, issn_l VARCHAR, issn VARCHAR[], is_oa BOOLEAN, is_in_doaj BOOLEAN, is_indexed_in_scopus BOOLEAN, is_core BOOLEAN, host_organization VARCHAR, host_organization_name VARCHAR, host_organization_lineage VARCHAR[], host_organization_lineage_names VARCHAR[], type VARCHAR), license VARCHAR, license_id VARCHAR, is_accepted BOOLEAN, is_published BOOLEAN)[]",
    "best_oa_location": "STRUCT(is_oa BOOLEAN, landing_page_url VARCHAR, pdf_url VARCHAR, source STRUCT(id VARCHAR, display_name VARCHAR, issn_l VARCHAR, issn VARCHAR[], is_oa BOOLEAN, is_in_doaj BOOLEAN, is_indexed_in_scopus BOOLEAN, is_core BOOLEAN, host_organization VARCHAR, host_organization_name VARCHAR, host_organization_lineage VARCHAR[], host_organization_lineage_names VARCHAR[], type VARCHAR), license VARCHAR, license_id VARCHAR, is_accepted BOOLEAN, is_published BOOLEAN)",
    "sustainable_development_goals": "STRUCT(id VARCHAR, display_name VARCHAR, score DOUBLE)[]",
    "grants": "STRUCT(funder VARCHAR, funder_display_name VARCHAR, award_id VARCHAR)[]",
    "datasets": "VARCHAR[]",
    "versions": "VARCHAR[]",
    "referenced_works_count": "BIGINT",
    "referenced_works": "VARCHAR[]",
    "related_works": "VARCHAR[]",
    "cited_by_api_url": "VARCHAR",
    "counts_by_year": "STRUCT(year BIGINT, cited_by_count BIGINT)[]",
    "updated_date": "DATE",
    "created_date": "DATE",
}
